
From: <tglx@linutronix.de>

To make spinlock/rwlock initialization consistent all over the kernel,
this patch converts explicit lock-initializers into spin_lock_init() and
rwlock_init() calls.

Currently, spinlocks and rwlocks are initialized in two different ways:

  lock = SPIN_LOCK_UNLOCKED
  spin_lock_init(&lock)
  
  rwlock = RW_LOCK_UNLOCKED
  rwlock_init(&rwlock)

this patch converts all explicit lock initializations to
spin_lock_init() or rwlock_init(). (Besides consistency this also helps
automatic lock validators and debugging code.)

The conversion was done with a script, it was verified manually and it
was reviewed, compiled and tested as far as possible on x86, ARM, PPC.

There is no runtime overhead or actual code change resulting out of this
patch, because spin_lock_init() and rwlock_init() are macros and are
thus equivalent to the explicit initialization method.

That's the second batch of the unifying patches.

Signed-off-by: Thomas Gleixner <tglx@linutronix.de>
Acked-by: Ingo Molnar <mingo@elte.hu>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/drivers/usb/input/hid-core.c  |    4 ++--
 25-akpm/drivers/usb/input/powermate.c |    2 +-
 25-akpm/drivers/usb/net/catc.c        |    4 ++--
 3 files changed, 5 insertions(+), 5 deletions(-)

diff -puN drivers/usb/input/hid-core.c~lock-initializer-unifying-batch-2-usb drivers/usb/input/hid-core.c
--- 25/drivers/usb/input/hid-core.c~lock-initializer-unifying-batch-2-usb	Thu Oct 28 15:55:25 2004
+++ 25-akpm/drivers/usb/input/hid-core.c	Thu Oct 28 15:55:25 2004
@@ -1695,8 +1695,8 @@ static struct hid_device *usb_hid_config
 
 	init_waitqueue_head(&hid->wait);
 	
-	hid->outlock = SPIN_LOCK_UNLOCKED;
-	hid->ctrllock = SPIN_LOCK_UNLOCKED;
+	spin_lock_init(&hid->outlock);
+	spin_lock_init(&hid->ctrllock);
 
 	hid->version = le16_to_cpu(hdesc->bcdHID);
 	hid->country = hdesc->bCountryCode;
diff -puN drivers/usb/input/powermate.c~lock-initializer-unifying-batch-2-usb drivers/usb/input/powermate.c
--- 25/drivers/usb/input/powermate.c~lock-initializer-unifying-batch-2-usb	Thu Oct 28 15:55:25 2004
+++ 25-akpm/drivers/usb/input/powermate.c	Thu Oct 28 15:55:25 2004
@@ -349,7 +349,7 @@ static int powermate_probe(struct usb_in
 		return -ENOMEM;
 	}
 
-	pm->lock = SPIN_LOCK_UNLOCKED;
+	spin_lock_init(&pm->lock);
 	init_input_dev(&pm->input);
 
 	/* get a handle to the interrupt data pipe */
diff -puN drivers/usb/net/catc.c~lock-initializer-unifying-batch-2-usb drivers/usb/net/catc.c
--- 25/drivers/usb/net/catc.c~lock-initializer-unifying-batch-2-usb	Thu Oct 28 15:55:25 2004
+++ 25-akpm/drivers/usb/net/catc.c	Thu Oct 28 15:55:25 2004
@@ -773,8 +773,8 @@ static int catc_probe(struct usb_interfa
 	catc->usbdev = usbdev;
 	catc->netdev = netdev;
 
-	catc->tx_lock = SPIN_LOCK_UNLOCKED;
-	catc->ctrl_lock = SPIN_LOCK_UNLOCKED;
+	spin_lock_init(&catc->tx_lock);
+	spin_lock_init(&catc->ctrl_lock);
 
 	init_timer(&catc->timer);
 	catc->timer.data = (long) catc;
_
